==> kubernetes-model-core-4.13.2-sources.jar: io/fabric8/kubernetes/api/model/GitRepoVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class GitRepoVolumeSourceFluentImpl<A extends GitRepoVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements GitRepoVolumeSourceFluent<A> {

    private String directory;
    private String repository;
    private String revision;

    public GitRepoVolumeSourceFluentImpl() { 
    }


    public GitRepoVolumeSourceFluentImpl(GitRepoVolumeSource instance) { 
        this.withDirectory(instance.getDirectory()); 
        this.withRepository(instance.getRepository()); 
        this.withRevision(instance.getRevision()); 
    }


    public String getDirectory() {
        return this.directory;
    }

    public A withDirectory(String directory) {
        this.directory=directory; return (A) this;
    }

    public Boolean hasDirectory() {
        return this.directory != null;
    }

    public A withNewDirectory(String arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public A withNewDirectory(StringBuilder arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public A withNewDirectory(StringBuffer arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public String getRepository() {
        return this.repository;
    }

    public A withRepository(String repository) {
        this.repository=repository; return (A) this;
    }

    public Boolean hasRepository() {
        return this.repository != null;
    }

    public A withNewRepository(String arg1) {
        return (A)withRepository(new String(arg1));
    }

    public A withNewRepository(StringBuilder arg1) {
        return (A)withRepository(new String(arg1));
    }

    public A withNewRepository(StringBuffer arg1) {
        return (A)withRepository(new String(arg1));
    }

    public String getRevision() {
        return this.revision;
    }

    public A withRevision(String revision) {
        this.revision=revision; return (A) this;
    }

    public Boolean hasRevision() {
        return this.revision != null;
    }

    public A withNewRevision(String arg1) {
        return (A)withRevision(new String(arg1));
    }

    public A withNewRevision(StringBuilder arg1) {
        return (A)withRevision(new String(arg1));
    }

    public A withNewRevision(StringBuffer arg1) {
        return (A)withRevision(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GitRepoVolumeSourceFluentImpl that = (GitRepoVolumeSourceFluentImpl) o;
        if (directory != null ? !directory.equals(that.directory) :that.directory != null) return false;
        if (repository != null ? !repository.equals(that.repository) :that.repository != null) return false;
        if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(directory,  repository,  revision,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/GitRepoVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class GitRepoVolumeSourceFluentImpl<A extends GitRepoVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements GitRepoVolumeSourceFluent<A> {

    private String directory;
    private String repository;
    private String revision;

    public GitRepoVolumeSourceFluentImpl() {
    }

    public GitRepoVolumeSourceFluentImpl(GitRepoVolumeSource instance) {
        this.withDirectory(instance.getDirectory()); 
        this.withRepository(instance.getRepository()); 
        this.withRevision(instance.getRevision()); 
    }

    public String getDirectory() {
        return this.directory;
    }

    public A withDirectory(String directory) {
        this.directory=directory; return (A) this;
    }

    public Boolean hasDirectory() {
        return this.directory != null;
    }

    public A withNewDirectory(StringBuilder arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public A withNewDirectory(int[] arg1,int arg2,int arg3) {
        return (A)withDirectory(new String(arg1, arg2, arg3));
    }

    public A withNewDirectory(char[] arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public A withNewDirectory(StringBuffer arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public A withNewDirectory(byte[] arg1,int arg2) {
        return (A)withDirectory(new String(arg1, arg2));
    }

    public A withNewDirectory(byte[] arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public A withNewDirectory(char[] arg1,int arg2,int arg3) {
        return (A)withDirectory(new String(arg1, arg2, arg3));
    }

    public A withNewDirectory(byte[] arg1,int arg2,int arg3) {
        return (A)withDirectory(new String(arg1, arg2, arg3));
    }

    public A withNewDirectory(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withDirectory(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewDirectory(String arg1) {
        return (A)withDirectory(new String(arg1));
    }

    public String getRepository() {
        return this.repository;
    }

    public A withRepository(String repository) {
        this.repository=repository; return (A) this;
    }

    public Boolean hasRepository() {
        return this.repository != null;
    }

    public A withNewRepository(StringBuilder arg1) {
        return (A)withRepository(new String(arg1));
    }

    public A withNewRepository(int[] arg1,int arg2,int arg3) {
        return (A)withRepository(new String(arg1, arg2, arg3));
    }

    public A withNewRepository(char[] arg1) {
        return (A)withRepository(new String(arg1));
    }

    public A withNewRepository(StringBuffer arg1) {
        return (A)withRepository(new String(arg1));
    }

    public A withNewRepository(byte[] arg1,int arg2) {
        return (A)withRepository(new String(arg1, arg2));
    }

    public A withNewRepository(byte[] arg1) {
        return (A)withRepository(new String(arg1));
    }

    public A withNewRepository(char[] arg1,int arg2,int arg3) {
        return (A)withRepository(new String(arg1, arg2, arg3));
    }

    public A withNewRepository(byte[] arg1,int arg2,int arg3) {
        return (A)withRepository(new String(arg1, arg2, arg3));
    }

    public A withNewRepository(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withRepository(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewRepository(String arg1) {
        return (A)withRepository(new String(arg1));
    }

    public String getRevision() {
        return this.revision;
    }

    public A withRevision(String revision) {
        this.revision=revision; return (A) this;
    }

    public Boolean hasRevision() {
        return this.revision != null;
    }

    public A withNewRevision(StringBuilder arg1) {
        return (A)withRevision(new String(arg1));
    }

    public A withNewRevision(int[] arg1,int arg2,int arg3) {
        return (A)withRevision(new String(arg1, arg2, arg3));
    }

    public A withNewRevision(char[] arg1) {
        return (A)withRevision(new String(arg1));
    }

    public A withNewRevision(StringBuffer arg1) {
        return (A)withRevision(new String(arg1));
    }

    public A withNewRevision(byte[] arg1,int arg2) {
        return (A)withRevision(new String(arg1, arg2));
    }

    public A withNewRevision(byte[] arg1) {
        return (A)withRevision(new String(arg1));
    }

    public A withNewRevision(char[] arg1,int arg2,int arg3) {
        return (A)withRevision(new String(arg1, arg2, arg3));
    }

    public A withNewRevision(byte[] arg1,int arg2,int arg3) {
        return (A)withRevision(new String(arg1, arg2, arg3));
    }

    public A withNewRevision(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withRevision(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewRevision(String arg1) {
        return (A)withRevision(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GitRepoVolumeSourceFluentImpl that = (GitRepoVolumeSourceFluentImpl) o;
        if (directory != null ? !directory.equals(that.directory) :that.directory != null) return false;
        if (repository != null ? !repository.equals(that.repository) :that.repository != null) return false;
        if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(directory,  repository,  revision,  super.hashCode());
    }

}
